sol.models.boards -- Boards — SoL 4 developers documentation

# `sol.models.boards` -- Boards

class `sol.models.board.` `Board`(**kwargs)

  A single board.

  This table contains the detailed scores of a single match.

  Since entering such details is very time-consuming, historically and usually only the final scores of the match are assigned.

  Note

  In normal boards coinsX is the number of carrommen of the opponent competitor still on the table at the end of the board; coins1 and coins2 are thus mutually exclusive (ie, one is zero) and the board is won by the competitor with a coins number greater than zero, with a score equal to that number plus possibly the points of the queen if pocketed by him.

  In training boards coins1 and coins2 are actually the number of misses of the respective competitors, in other words how many unsuccessful shots they made: the meaning is reversed, the board is won by the competitor with the lower number. The queen field has no meaning.

  `coins1`

    Coins of the first `competitor` in this board.

  `coins2`

    Coins of the second `competitor` in this board.

  `idboard`

    Primary key.

  `idmatch`

    Related `match`'s ID.

  `number`

    Progressive number of the board.

  `queen`

    Which competitor pocketed the Queen, if any.

  `serialize`(serializer)

    Reduce a single board to a simple dictionary.

    Parameters

      serializer -- a `Serializer` instance

    Returns

      a plain dictionary containing a flatified view of this board